@@ -63,6 +63,48 @@ static const char *infer_content_type(const char *fn) {
     return 0;
 }
 
+/* removes .. and . segments, control characters.
+   non-ASCII characters are retained.
+   returns -1 on error, i.e., any control chars (< 32), otherwise 0  */
+static int sanitize_path(char *path) {
+    unsigned char *src = (unsigned char*) path, *dst = (unsigned char*) path;
+    int pos = 0;
+    if (*path == '/')
+	*(dst++) = *(src++);
+
+    while (*src) {
+	if (!pos) {
+	    if (src[0] == '.') {
+		/* .. */
+		if (src[1] == '.' && (!src[2] || src[2] == '/')) {
+		    src += 2;
+		    continue;
+		}
+		/* . (harmless, but we still remove it) */
+		if (!src[1] || src[1] == '/') {
+		    src++;
+		    continue;
+		}
+	    }
+	}
+	if (*src == '/') {
+	    if (pos) { /* not a repeated / */
+		*(dst++) = *(src++);
+		pos = 0;
+	    } else /* repeated, just ignore */
+		src++;
+	    continue;
+	}
+	pos++;
+	if (*src >= 32)
+	    *(dst++) = *(src++);
+	else
+	    return -1;
+    }
+    *dst = 0;
+    return 0;
+}
+
 static void http_request(http_request_t *req, http_result_t *res) {
     FILE *f;
     char *s;
@@ -71,7 +113,10 @@ static void http_request(http_request_t *req, http_result_t *res) {
     int not_modified = 0, add_slash = 0;
     const char *append_headers = 0, *c_type = 0;
 
+#ifdef RSERV_DEBUG
     fprintf(stderr, "----\nINFO: request for '%s', Date: %s, headers:\n%s\n", req->url, posix2http(req->date), req->headers ? req->headers : "<NONE>");
+#endif
+
     /* leave room for ".gz\0" plus leading slash */
     if (req->url[0] != '/' && doc_root_len && doc_root[doc_root_len - 1] != '/') add_slash = 1;
     s = (char*) malloc(strlen(req->url) + doc_root_len + 8);
@@ -87,9 +132,8 @@ static void http_request(http_request_t *req, http_result_t *res) {
     }
 
     /* FIXME: technically, the processing of regular, static files
-       should also be jsut a handler -- move the code below into one. */
-
-    if (stat(s, &st) || !(f = fopen(s, "rb"))) {
+       should also be just a handler -- move the code below into one. */
+    if (sanitize_path(s) || stat(s, &st) || !(f = fopen(s, "rb"))) {
         free(s);
 	res->err = strdup("Path not found");
 	res->code = 404;
@@ -97,7 +141,6 @@ static void http_request(http_request_t *req, http_result_t *res) {
     }
 
     c_type = infer_content_type(s);
-
     /* check for conditional GET */
     if (req->headers) {
 	const char *if_mod = get_header(req, "If-Modified-Since");
